# encoding: utf-8
require 'test_helper'

class BookPageTest < TestCase

  def setup
    VCR.insert_cassette 'book'
    @book = OzonParser::Pages::Book.new(id: '7360633')
    @book2 = OzonParser::Pages::Book.new(url: "http://www.ozon.ru/context/detail/id/10422848/")
  end

  def teardown
    VCR.eject_cassette
  end

  def test_correct_url
    assert_equal @book.url, "http://www.ozon.ru/context/detail/id/7360633/"
    assert_equal @book2.url, "http://www.ozon.ru/context/detail/id/10422848/"
  end

  def test_correct_title
    assert_equal @book.title, "Идеальный программист. Как стать профессионалом разработки ПО"
    assert_equal @book2.title, "Дикая природа России / Wildlife in Russia"
  end

  def test_cover_url
    assert_equal @book.cover_url, "http://static1.ozone.ru/multimedia/books_covers/1003645102.jpg"
    assert_equal @book2.cover_url, "http://static.ozone.ru/multimedia/books_covers/1005266671.jpg"
  end

  def test_categories
    assert_equal @book.categories, ["Книги", "Нехудожественная литература", 
      "Компьютерная литература", 
      "Разработка программного обеспечения", 
      "Алгоритмы и методы. Искусство программирования", 
      "Идеальный программист. Как стать профессионалом разработки ПО"]

    assert_equal @book2.categories, ["Книги", "Нехудожественная литература",
     "Научная и техническая литература", "Естественные науки", "Биологические науки", 
     "Общая биология. Палеонтология", "Дикая природа России / Wildlife in Russia"]
  end

  def test_type
    assert_equal @book.type, "Книги"
    assert_equal @book2.type, "Книги"
  end

  def test_tags
    assert_equal @book.tags, ["Нехудожественная литература", 
      "Компьютерная литература", 
      "Разработка программного обеспечения", 
      "Алгоритмы и методы. Искусство программирования"]

    assert_equal @book2.tags, ["Нехудожественная литература",
     "Научная и техническая литература", "Естественные науки", "Биологические науки", 
     "Общая биология. Палеонтология"]
  end

  def test_author
    assert_equal @book.author, "Роберт К. Мартин"
    assert_equal @book2.author, "Валерий Малеев"
  end

  def test_languages
    assert_equal @book.language, ["Русский"]
    assert_equal @book2.language, ["Русский", "Английский"]
  end

  def test_isbn
    assert_equal @book.isbn, ["978-5-459-01044-2","978-0137081073"]
    assert_equal @book2.isbn, ["978-5-91657-436-4"]
  end

  def test_pages
    assert_equal @book.pages, 224
    assert_equal @book2.pages, 496
  end

end